@@ -19,7 +19,6 @@
 
 
 import pkg_resources
-
 import sphinx_rtd_theme
 
 html_theme = "sphinx_rtd_theme"
@@ -27,7 +26,7 @@ html_theme = "sphinx_rtd_theme"
 html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
 
 project = "Rich"
-copyright = "2020, Will McGugan"
+copyright = "Will McGugan"
 author = "Will McGugan"
 
 # The full version, including alpha/beta/rc tags
@@ -70,3 +69,9 @@ exclude_patterns = []
 html_static_path = ["_static"]
 
 intersphinx_mapping = {"python": ("http://docs.python.org/3", None)}
+
+autodoc_typehints = "description"
+
+html_css_files = [
+    "https://cdnjs.cloudflare.com/ajax/libs/firacode/6.2.0/fira_code.min.css"
+]
