@@ -61,6 +61,47 @@ def test_rule_cjk():
     assert console.file.getvalue() == expected
 
 
+@pytest.mark.parametrize(
+    "align,outcome",
+    [
+        ("center", "───\n"),
+        ("left", "… ─\n"),
+        ("right", "─ …\n"),
+    ],
+)
+def test_rule_not_enough_space_for_title_text(align, outcome):
+    console = Console(width=3, file=io.StringIO(), record=True)
+    console.rule("Hello!", align=align)
+    assert console.file.getvalue() == outcome
+
+
+def test_rule_center_aligned_title_not_enough_space_for_rule():
+    console = Console(width=4, file=io.StringIO(), record=True)
+    console.rule("ABCD")
+    assert console.file.getvalue() == "────\n"
+
+
+@pytest.mark.parametrize("align", ["left", "right"])
+def test_rule_side_aligned_not_enough_space_for_rule(align):
+    console = Console(width=2, file=io.StringIO(), record=True)
+    console.rule("ABCD", align=align)
+    assert console.file.getvalue() == "──\n"
+
+
+@pytest.mark.parametrize(
+    "align,outcome",
+    [
+        ("center", "─ … ─\n"),
+        ("left", "AB… ─\n"),
+        ("right", "─ AB…\n"),
+    ],
+)
+def test_rule_just_enough_width_available_for_title(align, outcome):
+    console = Console(width=5, file=io.StringIO(), record=True)
+    console.rule("ABCD", align=align)
+    assert console.file.getvalue() == outcome
+
+
 def test_characters():
     console = Console(
         width=16,
